pub struct AccountLeaf {
pub cash: i128,
pub nonce: u64,
pub margin_mode: u8,
pub liquidation_state: u8,
}Expand description
Account metadata leaf. Key: keccak256(address || “account”)
cash is the ledger balance scaled by 1e8 (from Decimal).
margin_mode: 0 = Standard, 1 = Portfolio.
liquidation_state: 0 = Healthy, 1 = PreLiquidation, 2 = InLiquidation, 3 = Liquidated.
Fields
cash: i128Ledger cash balance, scaled 1e8. Preserves full Decimal precision.
nonce: u64margin_mode: u8liquidation_state: u8Trait Implementations
Sourceimpl BorshDeserialize for AccountLeaf
impl BorshDeserialize for AccountLeaf
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for AccountLeaf
impl BorshSerialize for AccountLeaf
Sourceimpl Clone for AccountLeaf
impl Clone for AccountLeaf
Sourcefn clone(&self) -> AccountLeaf
fn clone(&self) -> AccountLeaf
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AccountLeaf
impl Debug for AccountLeaf
Sourceimpl<'de> Deserialize<'de> for AccountLeaf
impl<'de> Deserialize<'de> for AccountLeaf
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for AccountLeaf
impl PartialEq for AccountLeaf
Sourceimpl Serialize for AccountLeaf
impl Serialize for AccountLeaf
impl StructuralPartialEq for AccountLeaf