pub struct GlobalLeaf {
pub next_order_id: u64,
pub next_trade_id: u64,
pub command_chain_root: [u8; 32],
pub command_chain_seq: u64,
}Expand description
Global counters leaf (singleton). Key: keccak256(“global”)
Fields
next_order_id: u64next_trade_id: u64command_chain_root: [u8; 32]command_chain_seq: u64Trait Implementations
Sourceimpl BorshDeserialize for GlobalLeaf
impl BorshDeserialize for GlobalLeaf
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for GlobalLeaf
impl BorshSerialize for GlobalLeaf
Sourceimpl Clone for GlobalLeaf
impl Clone for GlobalLeaf
Sourcefn clone(&self) -> GlobalLeaf
fn clone(&self) -> GlobalLeaf
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GlobalLeaf
impl Debug for GlobalLeaf
Sourceimpl<'de> Deserialize<'de> for GlobalLeaf
impl<'de> Deserialize<'de> for GlobalLeaf
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for GlobalLeaf
impl PartialEq for GlobalLeaf
Sourceimpl Serialize for GlobalLeaf
impl Serialize for GlobalLeaf
impl StructuralPartialEq for GlobalLeaf